pub struct ScrollSample { /* private fields */ }Expand description
One scroll transition retained in the frame input snapshot.
Implementations
Sourceimpl ScrollSample
impl ScrollSample
Sourcepub const fn delta(self) -> ScrollDelta
pub const fn delta(self) -> ScrollDelta
Returns the precise or coarse scroll delta supplied by the platform.
Sourcepub const fn position(self) -> LogicalPosition
pub const fn position(self) -> LogicalPosition
Returns the pointer position associated with the scroll transition.