InputSnapshot

Struct InputSnapshot 

pub struct InputSnapshot { /* private fields */ }
Held controls and transitions accumulated for one game frame.

Implementations

Source

impl InputSnapshot

pub const fn focused(&self) -> bool

Returns whether the application window currently has keyboard focus.

pub const fn modifiers(&self) -> Modifiers

Returns the latest aggregate modifier state.

pub const fn pointer_position(&self) -> Option<LogicalPosition>

Returns the latest known pointer position in logical window coordinates.

pub fn key_held(&self, key: KeyCode) -> bool

Returns whether key is currently held.

pub fn key_pressed(&self, key: KeyCode) -> bool

Returns whether key became pressed during the current frame.

pub fn key_released(&self, key: KeyCode) -> bool

Returns whether key became released during the current frame.

pub fn pointer_button_held(&self, button: PointerButton) -> bool

Returns whether button is currently held.

pub fn pointer_button_pressed(&self, button: PointerButton) -> bool

Returns whether button became pressed during the current frame.

pub fn pointer_button_released(&self, button: PointerButton) -> bool

Returns whether button became released during the current frame.

pub fn scroll(&self) -> &[ScrollSample]

Returns the ordered scroll transitions accumulated during the current frame.